diff --git a/Makefile b/Makefile
index bcd092d..7281724 100644
--- a/Makefile
+++ b/Makefile
@@ -184,7 +184,7 @@ else
 	ECHO=:
 endif
 
-OBJS = mdadm.o config.o policy.o mdstat.o  ReadMe.o uuid.o util.o maps.o lib.o udev.o \
+OBJS = mdadm.o policy.o mdstat.o  ReadMe.o uuid.o util.o maps.o lib.o udev.o \
        Manage.o Assemble.o Build.o \
        Create.o Detail.o Examine.o Grow.o mdmonitor.o dlink.o Kill.o Query.o \
        Incremental.o Dump.o \
@@ -208,8 +208,10 @@ MON_OBJS = mdmon.o monitor.o managemon.o uuid.o util.o maps.o mdstat.o sysfs.o c
 
 MON_SRCS = $(patsubst %.o,%.c,$(MON_OBJS))
 
-STATICSRC = pwgr.c
-STATICOBJS = pwgr.o
+# STATICSRC = pwgr.c
+# STATICOBJS = pwgr.o
+STATICOBJS = config_static.o
+SHAREDOBJS = config_shared.o
 
 all : mdadm mdmon
 man : mdadm.man md.man mdadm.conf.man mdmon.man raid6check.man
@@ -231,8 +233,14 @@ everything-test: all swap_super test_stripe \
 %.o: %.c
 	$(CC) $(CFLAGS) $(CPPFLAGS) $(COVERITY_FLAGS) -o $@ -c $<
 
-mdadm : $(OBJS) | check_rundir
-	$(CC) $(CFLAGS) $(LDFLAGS) -o mdadm $(OBJS) $(LDLIBS)
+config_shared.o: config.c
+	$(CC) $(CFLAGS) $(CPPFLAGS) $(COVERITY_FLAGS) -o $@ -c $<
+
+config_static.o: config.c
+	$(CC) $(CFLAGS) $(CPPFLAGS) $(COVERITY_FLAGS) -D_MDADM_PRIV_STATIC -o $@ -c $<
+
+mdadm : $(OBJS) $(SHAREDOBJS) | check_rundir
+	$(CC) $(CFLAGS) $(LDFLAGS) -o mdadm $(OBJS) $(SHAREDOBJS) $(LDLIBS)
 
 mdadm.static : $(OBJS) $(STATICOBJS)
 	$(CC) $(CFLAGS) $(LDFLAGS) -static -o mdadm.static $(OBJS) $(STATICOBJS) $(LDLIBS)
@@ -353,7 +361,7 @@ test: mdadm mdmon test_stripe swap_super raid6check
 	@echo "Please run './test' as root"
 
 clean :
-	rm -f mdadm mdmon $(OBJS) $(MON_OBJS) $(STATICOBJS) core *.man \
+	rm -f mdadm mdmon $(OBJS) $(MON_OBJS) $(STATICOBJS) $(SHAREDOBJS) core *.man \
 	mdadm.tcc mdadm.uclibc mdadm.static *.orig *.porig *.rej *.alt \
 	.merge_file_* mdadm.Os mdadm.O2 mdmon.O2 swap_super init.cpio.gz \
 	mdadm.uclibc.static test_stripe raid6check raid6check.o mdmon mdadm.8
diff --git a/config.c b/config.c
index 8a8ae5e..1dd7d55 100644
--- a/config.c
+++ b/config.c
@@ -421,12 +421,14 @@ static void createline(char *line)
 			}
 			createinfo.uid = strtoul(w + 6, &ep, 10);
 			if (*ep != 0) {
+#if !defined(_MDADM_PRIV_STATIC)
 				struct passwd *pw;
 				/* must be a name */
 				pw = getpwnam(w + 6);
 				if (pw)
 					createinfo.uid = pw->pw_uid;
 				else
+#endif
 					pr_err("CREATE user %s not found\n",
 					       w + 6);
 			}
@@ -437,12 +439,14 @@ static void createline(char *line)
 			}
 			createinfo.gid = strtoul(w + 6, &ep, 10);
 			if (*ep != 0) {
+#if !defined(_MDADM_PRIV_STATIC)
 				struct group *gr;
 				/* must be a name */
 				gr = getgrnam(w + 6);
 				if (gr)
 					createinfo.gid = gr->gr_gid;
 				else
+#endif
 					pr_err("CREATE group %s not found\n",
 					       w + 6);
 			}
